@@ -704,7 +704,7 @@ static int imap_reopen_mailbox (CONTEXT *ctx, int *index_hint)
       }
       if (!found)
       {
-	for (j = 0; j < i; j++)
+	for (j = 0; j < i && j < old_msgcount; j++)
 	{
 	  if (old_hdrs[j] == NULL)
 	    continue;
@@ -783,7 +783,7 @@ static int imap_exec (char *buf, size_t buflen,
   }
   while (mutt_strncmp (buf, seq, SEQLEN) != 0);
 
-  if (!selctx->closing && 
+  if (selctx && !selctx->closing && 
       (SELCTX_DATA->status == IMAP_NEW_MAIL || 
        SELCTX_DATA->status == IMAP_EXPUNGE))
   {
@@ -1218,6 +1218,15 @@ int imap_fetch_message (MESSAGE *msg, CONTEXT *ctx, int msgno)
   rewind (msg->fp);
   mutt_free_envelope (&ctx->hdrs[msgno]->env);
   ctx->hdrs[msgno]->env = mutt_read_rfc822_header (msg->fp, ctx->hdrs[msgno],0);
+  fgets (buf, sizeof (buf), msg->fp);
+  while (!feof (msg->fp))
+  {
+    ctx->hdrs[msgno]->lines++;
+    fgets (buf, sizeof (buf), msg->fp);
+  }
+
+  ctx->hdrs[msgno]->content->length = ftell (msg->fp) - 
+                                        ctx->hdrs[msgno]->content->offset;
 
   /* This needs to be done in case this is a multipart message */
 
