@@ -37,6 +37,8 @@
 
 #ifdef HAVE_SYSEXITS_H
 #include <sysexits.h>
+#else /* Make sure EX_OK is defined <philiph@pobox.com> */
+#define EX_OK 0
 #endif
 
 extern char RFC822Specials[];
@@ -884,7 +886,7 @@ static void mutt_set_encoding (BODY *b, CONTENT *info)
     else
       b->encoding = ENC7BIT;
   }
-  else if (b->type == TYPEMESSAGE)
+  else if (b->type == TYPEMESSAGE  || b->type == TYPEMULTIPART)
   {
     if (info->lobin || info->hibin)
     {
